#!/usr/bin/python
# -*- coding: utf-8 -*-

# Copyright (c) 2021, Cisco Systems
# GNU General Public License v3.0+ (see LICENSE or https://www.gnu.org/licenses/gpl-3.0.txt)

DOCUMENTATION = r"""
---
module: energy_summary_analytics
short_description: Resource module for Energy Summary Analytics
description:
  - Manage operation create of the resource Energy Summary Analytics. - > Retrieve the summary analytics data related to device
    energy consumption for all devices, including network devices and clients assigned to specific sites. For detailed information
    about the usage of the API, please refer to the Open API specification document - https //github.com/cisco-en-programmability/catalyst-center-
    api-specs/blob/main/Assurance/CE_Cat_Center_Org-deviceEnergy_1.0-1.0.1-resolved.yaml.
version_added: '6.18.0'
extends_documentation_fragment:
  - cisco.dnac.module
author: Rafael Campos (@racampos)
options:
  aggregateAttributes:
    description: Energy Summary Analytics's aggregateAttributes.
    elements: dict
    suboptions:
      function:
        description: Function.
        type: str
      name:
        description: Name.
        type: str
    type: list
  attributes:
    description: Attributes.
    elements: str
    type: list
  endTime:
    description: End Time.
    type: int
  filters:
    description: Energy Summary Analytics's filters.
    elements: dict
    suboptions:
      filters:
        description: Energy Summary Analytics's filters.
        elements: dict
        suboptions:
          key:
            description: Key.
            type: str
          operator:
            description: Operator.
            type: str
          value:
            description: Value.
            elements: str
            type: list
        type: list
      logicalOperator:
        description: Logical Operator.
        type: str
    type: list
  groupBy:
    description: Group By.
    elements: str
    type: list
  headers:
    description: Additional headers.
    type: dict
  page:
    description: Energy Summary Analytics's page.
    suboptions:
      limit:
        description: Limit.
        type: int
      offset:
        description: Offset.
        type: int
      sortBy:
        description: Energy Summary Analytics's sortBy.
        elements: dict
        suboptions:
          function:
            description: Function.
            type: str
          name:
            description: Name.
            type: str
          order:
            description: Order.
            type: str
        type: list
    type: dict
  startTime:
    description: Start Time.
    type: int
requirements:
  - dnacentersdk >= 2.11.0
  - python >= 3.12
seealso:
  - name: Cisco DNA Center documentation for Know Your Network GetEnergySummaryAnalytics
    description: Complete reference of the GetEnergySummaryAnalytics API.
    link: https://developer.cisco.com/docs/dna-center/#!get-energy-summary-analytics
notes:
  - SDK Method used are
    know_your_network.KnowYourNetwork.get_energy_summary_analytics,
  - Paths used are
    post /dna/data/api/v1/energy/summaryAnalytics,
"""

EXAMPLES = r"""
---
- name: Create
  cisco.dnac.energy_summary_analytics:
    dnac_host: "{{dnac_host}}"
    dnac_username: "{{dnac_username}}"
    dnac_password: "{{dnac_password}}"
    dnac_verify: "{{dnac_verify}}"
    dnac_port: "{{dnac_port}}"
    dnac_version: "{{dnac_version}}"
    dnac_debug: "{{dnac_debug}}"
    aggregateAttributes:
      - function: string
        name: string
    attributes:
      - string
    endTime: 0
    filters:
      - filters:
          - key: string
            operator: string
            value:
              - string
        logicalOperator: string
    groupBy:
      - string
    headers: '{{my_headers | from_json}}'
    page:
      limit: 0
      offset: 0
      sortBy:
        - function: string
          name: string
          order: string
    startTime: 0
"""
RETURN = r"""
dnac_response:
  description: A dictionary or list with the response returned by the Cisco DNAC Python SDK
  returned: always
  type: dict
  sample: >
    {
      "response": {
        "groups": [
          {
            "id": "string",
            "attributes": [
              {
                "name": "string",
                "value": "string"
              }
            ],
            "aggregateAttributes": [
              {
                "name": "string",
                "function": "string",
                "value": 0
              }
            ]
          }
        ]
      },
      "page": {
        "limit": 0,
        "offset": 0,
        "count": 0,
        "sortBy": [
          {
            "name": "string",
            "order": "string",
            "function": "string"
          }
        ]
      },
      "version": "string"
    }
"""



#!/usr/bin/python
# -*- coding: utf-8 -*-

# Copyright (c) 2021, Cisco Systems
# GNU General Public License v3.0+ (see LICENSE or https://www.gnu.org/licenses/gpl-3.0.txt)

DOCUMENTATION = r"""
---
module: custom_issue_definitions_info
short_description: Information module for Custom Issue Definitions
description:
  - Get all Custom Issue Definitions.
  - Get Custom Issue Definitions by id. - > Get the custom issue definition for the given custom issue definition Id. For
    detailed information about the usage of the API, please refer to the Open API specification document - https //github.com/cisco-en-
    programmability/catalyst-center-api-specs/blob/main/Assurance/CE_Cat_Center_Org- AssuranceUserDefinedIssueAPIs-1.0.0-resolved.yaml.
    - > Retrieve the existing syslog-based custom issue definitions. The supported filters are id, name, profileId, definition
    enable status, priority, severity, facility and mnemonic. The issue definition configurations may vary across profiles,
    hence specifying the profile Id in the query parameter is important and the default profile is global.
version_added: '6.15.0'
extends_documentation_fragment:
  - cisco.dnac.module_info
author: Rafael Campos (@racampos)
options:
  headers:
    description: Additional headers.
    type: dict
  id:
    description:
      - >
        Id query parameter. The custom issue definition identifier and unique identifier across the
        profile.Examples id=6bef213c-19ca-4170-8375-b694e251101c (single entity uuid requested)
        id=6bef213c-19ca-4170-8375-b694e251101c&id=19ca-4170-8375-b694e251101c-6bef213c (multiple Id request in
        the query param).
    type: str
  profileId:
    description:
      - >
        ProfileId query parameter. The profile identifier to fetch the profile associated custom issue
        definitions. The default is global. For the custom profile, it is profile UUID. Example
        3fa85f64-5717-4562-b3fc-2c963f66afa6.
    type: str
  name:
    description:
      - Name query parameter. The list of UDI issue names.
    type: str
  priority:
    description:
      - >
        Priority query parameter. The Issue priority value, possible values are P1, P2, P3, P4. P1 A critical
        issue that needs immediate attention and can have a wide impact on network operations. P2 A major issue
        that can potentially impact multiple devices or clients. P3 A minor issue that has a localized or
        minimal impact. P4 A warning issue that may not be an immediate problem but addressing it can optimize
        the network performance.
    type: str
  isEnabled:
    description:
      - IsEnabled query parameter. The enable status of the custom issue definition, either true or false.
    type: bool
  severity:
    description:
      - >
        Severity query parameter. The syslog severity level. 0 Emergency 1 Alert, 2 Critical. 3 Error, 4
        Warning, 5 Notice, 6 Info. Examples severity=1&severity=2 (multi value support with & separator).
    type: float
  facility:
    description:
      - Facility query parameter. The syslog facility name.
    type: str
  mnemonic:
    description:
      - Mnemonic query parameter. The syslog mnemonic name.
    type: str
  limit:
    description:
      - Limit query parameter. The maximum number of records to return.
    type: int
  offset:
    description:
      - >
        Offset query parameter. Specifies the starting point within all records returned by the API. It's one
        based offset. The starting value is 1.
    type: int
  sortBy:
    description:
      - SortBy query parameter. A field within the response to sort by.
    type: str
  order:
    description:
      - Order query parameter. The sort order of the field ascending or descending.
    type: str
requirements:
  - dnacentersdk >= 2.11.0
  - python >= 3.12
seealso:
  - name: Cisco DNA Center documentation for Issues GetAllTheCustomIssueDefinitionsBasedOnTheGivenFilters
    description: Complete reference of the GetAllTheCustomIssueDefinitionsBasedOnTheGivenFilters API.
    link: https://developer.cisco.com/docs/dna-center/#!get-all-the-custom-issue-definitions-based-on-the-given-filters
  - name: Cisco DNA Center documentation for Issues GetTheCustomIssueDefinitionForTheGivenCustomIssueDefinitionId
    description: Complete reference of the GetTheCustomIssueDefinitionForTheGivenCustomIssueDefinitionId API.
    link: https://developer.cisco.com/docs/dna-center/#!get-the-custom-issue-definition-for-the-given-custom-issue-definition-id
notes:
  - SDK Method used are
    issues.Issues.get_all_the_custom_issue_definitions_based_on_the_given_filters,
    issues.Issues.get_the_custom_issue_definition_for_the_given_custom_issue_definition_id,
  - Paths used are
    get /dna/intent/api/v1/customIssueDefinitions,
    get /dna/intent/api/v1/customIssueDefinitions/{id},
"""

EXAMPLES = r"""
---
- name: Get all Custom Issue Definitions
  cisco.dnac.custom_issue_definitions_info:
    dnac_host: "{{dnac_host}}"
    dnac_username: "{{dnac_username}}"
    dnac_password: "{{dnac_password}}"
    dnac_verify: "{{dnac_verify}}"
    dnac_port: "{{dnac_port}}"
    dnac_version: "{{dnac_version}}"
    dnac_debug: "{{dnac_debug}}"
    headers: "{{my_headers | from_json}}"
    id: string
    profileId: string
    name: string
    priority: string
    isEnabled: true
    severity: 0
    facility: string
    mnemonic: string
    limit: 0
    offset: 0
    sortBy: string
    order: string
  register: result
- name: Get Custom Issue Definitions by id
  cisco.dnac.custom_issue_definitions_info:
    dnac_host: "{{dnac_host}}"
    dnac_username: "{{dnac_username}}"
    dnac_password: "{{dnac_password}}"
    dnac_verify: "{{dnac_verify}}"
    dnac_port: "{{dnac_port}}"
    dnac_version: "{{dnac_version}}"
    dnac_debug: "{{dnac_debug}}"
    headers: "{{my_headers | from_json}}"
    id: string
  register: result
"""
RETURN = r"""
dnac_response:
  description: A dictionary or list with the response returned by the Cisco DNAC Python SDK
  returned: always
  type: dict
  sample: >
    {
      "response": {
        "id": "string",
        "name": "string",
        "description": "string",
        "profileId": "string",
        "triggerId": "string",
        "rules": [
          {
            "type": "string",
            "severity": 0,
            "facility": "string",
            "mnemonic": "string",
            "pattern": "string",
            "occurrences": 0,
            "durationInMinutes": 0
          }
        ],
        "isEnabled": true,
        "priority": "string",
        "isDeletable": true,
        "isNotificationEnabled": true,
        "createdTime": 0,
        "lastUpdatedTime": 0
      }
    }
"""



#!/usr/bin/python
# -*- coding: utf-8 -*-

# Copyright (c) 2021, Cisco Systems
# GNU General Public License v3.0+ (see LICENSE or https://www.gnu.org/licenses/gpl-3.0.txt)

DOCUMENTATION = r"""
---
module: security_advisories_trigger_scan
short_description: Resource module for Security Advisories Trigger Scan
description:
  - Manage operation create of the resource Security Advisories Trigger Scan. - > Triggers a security advisories scan for
    the supported network devices. The supported devices are switches, routers and wireless controllers with IOS and IOS-XE.
    If a device is not supported, the SecurityAdvisoryNetworkDevice scanStatus will be Failed with appropriate comments.
version_added: '6.17.0'
extends_documentation_fragment:
  - cisco.dnac.module
author: Rafael Campos (@racampos)
options:
  failedDevicesOnly:
    description: FailedDevicesOnly query parameter. Used to specify if the scan should run only for the network devices that
      failed during the previous scan. If not specified, this parameter defaults to false.
    type: bool
requirements:
  - dnacentersdk >= 2.11.0
  - python >= 3.12
seealso:
  - name: Cisco DNA Center documentation for Compliance TriggersASecurityAdvisoriesScanForTheSupportedNetworkDevices
    description: Complete reference of the TriggersASecurityAdvisoriesScanForTheSupportedNetworkDevices API.
    link: https://developer.cisco.com/docs/dna-center/#!triggers-a-security-advisories-scan-for-the-supported-network-devices
notes:
  - SDK Method used are
    compliance.Compliance.triggers_a_security_advisories_scan_for_the_supported_network_devices,
  - Paths used are
    post /dna/intent/api/v1/securityAdvisories/triggerScan,
"""

EXAMPLES = r"""
---
- name: Create
  cisco.dnac.security_advisories_trigger_scan:
    dnac_host: "{{dnac_host}}"
    dnac_username: "{{dnac_username}}"
    dnac_password: "{{dnac_password}}"
    dnac_verify: "{{dnac_verify}}"
    dnac_port: "{{dnac_port}}"
    dnac_version: "{{dnac_version}}"
    dnac_debug: "{{dnac_debug}}"
    failedDevicesOnly: true
"""
RETURN = r"""
dnac_response:
  description: A dictionary or list with the response returned by the Cisco DNAC Python SDK
  returned: always
  type: dict
  sample: >
    {
      "version": "string",
      "response": {
        "count": 0
      }
    }
"""



#!/usr/bin/python
# -*- coding: utf-8 -*-

# Copyright (c) 2021, Cisco Systems
# GNU General Public License v3.0+ (see LICENSE or https://www.gnu.org/licenses/gpl-3.0.txt)

DOCUMENTATION = r"""
---
module: roles_v2
short_description: Resource module for Roles V2
description:
  - Manage operations create, update and delete of the resource Roles V2.
  - Add a new role into system v2-.
  - Delete a role in the system.
  - Update a role in the system v2-.
version_added: '6.46.0'
extends_documentation_fragment:
  - cisco.dnac.module
author: Rafael Campos (@racampos)
options:
  description:
    description: Description of role.
    type: str
  id:
    description: Id path parameter. The Id of the role to be deleted.
    type: str
  name:
    description: Name of the role.
    type: str
  permissions:
    description: Roles V2's permissions.
    elements: dict
    suboptions:
      operations:
        description: List of operations allowed for the application. Possible values are "gRead", "gCreate", "gUpdate", "gRemove",
          or some combination of these.
        elements: str
        type: list
      type:
        description: Name of the application in the System.
        type: str
    type: list
requirements:
  - dnacentersdk >= 2.11.0
  - python >= 3.12
seealso:
  - name: Cisco DNA Center documentation for User and Roles AddRoleV2
    description: Complete reference of the AddRoleV2 API.
    link: https://developer.cisco.com/docs/dna-center/#!add-role-v-2
  - name: Cisco DNA Center documentation for User and Roles DeleteRoleV2
    description: Complete reference of the DeleteRoleV2 API.
    link: https://developer.cisco.com/docs/dna-center/#!delete-role-v-2
  - name: Cisco DNA Center documentation for User and Roles UpdateRoleV2
    description: Complete reference of the UpdateRoleV2 API.
    link: https://developer.cisco.com/docs/dna-center/#!update-role-v-2
notes:
  - SDK Method used are
    userand_roles.UserandRoles.add_role_v2,
    userand_roles.UserandRoles.delete_role_v2,
    userand_roles.UserandRoles.update_role_v2,
  - Paths used are
    post /dna/system/api/v2/roles,
    delete /dna/system/api/v2/roles/{id},
    put /dna/system/api/v2/roles/{id},
"""

EXAMPLES = r"""
---
- name: Create
  cisco.dnac.roles_v2:
    dnac_host: "{{dnac_host}}"
    dnac_username: "{{dnac_username}}"
    dnac_password: "{{dnac_password}}"
    dnac_verify: "{{dnac_verify}}"
    dnac_port: "{{dnac_port}}"
    dnac_version: "{{dnac_version}}"
    dnac_debug: "{{dnac_debug}}"
    state: present
    description: string
    name: string
    permissions:
      - operations:
          - string
        type: string
- name: Delete by id
  cisco.dnac.roles_v2:
    dnac_host: "{{dnac_host}}"
    dnac_username: "{{dnac_username}}"
    dnac_password: "{{dnac_password}}"
    dnac_verify: "{{dnac_verify}}"
    dnac_port: "{{dnac_port}}"
    dnac_version: "{{dnac_version}}"
    dnac_debug: "{{dnac_debug}}"
    state: absent
    id: string
- name: Update by id
  cisco.dnac.roles_v2:
    dnac_host: "{{dnac_host}}"
    dnac_username: "{{dnac_username}}"
    dnac_password: "{{dnac_password}}"
    dnac_verify: "{{dnac_verify}}"
    dnac_port: "{{dnac_port}}"
    dnac_version: "{{dnac_version}}"
    dnac_debug: "{{dnac_debug}}"
    state: present
    description: string
    id: string
    name: string
    permissions:
      - operations:
          - string
        type: string
"""
RETURN = r"""
dnac_response:
  description: A dictionary or list with the response returned by the Cisco DNAC Python SDK
  returned: always
  type: dict
  sample: >
    {
      "id": "string",
      "name": "string",
      "description": "string",
      "permissions": [
        {
          "privilege": "string",
          "id": "string"
        }
      ],
      "type": "string",
      "version": "string",
      "meta": {
        "created": "string",
        "createdBy": "string",
        "lastModified": "string",
        "lastModifiedBy": "string"
      }
    }
"""



#!/usr/bin/python
# -*- coding: utf-8 -*-

# Copyright (c) 2021, Cisco Systems
# GNU General Public License v3.0+ (see LICENSE or https://www.gnu.org/licenses/gpl-3.0.txt)

DOCUMENTATION = r"""
---
module: cli_credential
short_description: Resource module for Cli Credential
description:
  - Manage operations create and update of the resource Cli Credential.
  - Adds global CLI credential.
  - Updates global CLI credentials.
version_added: '3.1.0'
extends_documentation_fragment:
  - cisco.dnac.module
author: Rafael Campos (@racampos)
options:
  comments:
    description: Comments to identify the CLI credential.
    type: str
  credentialType:
    description: Credential type to identify the application that uses the CLI credential.
    type: str
  description:
    description: Description for CLI Credentials.
    type: str
  enablePassword:
    description: CLI Enable Password.
    type: str
  id:
    description: Id of the CLI Credential in UUID format.
    type: str
  instanceTenantId:
    description: Deprecated.
    type: str
  instanceUuid:
    description: Deprecated.
    type: str
  password:
    description: CLI Password.
    type: str
  username:
    description: CLI Username.
    type: str
requirements:
  - dnacentersdk >= 2.11.0
  - python >= 3.12
seealso:
  - name: Cisco DNA Center documentation for Discovery CreateCLICredentials
    description: Complete reference of the CreateCLICredentials API.
    link: https://developer.cisco.com/docs/dna-center/#!create-cli-credentials
  - name: Cisco DNA Center documentation for Discovery UpdateCLICredentials
    description: Complete reference of the UpdateCLICredentials API.
    link: https://developer.cisco.com/docs/dna-center/#!update-cli-credentials
notes:
  - SDK Method used are
    discovery.Discovery.create_cli_credentials,
    discovery.Discovery.update_cli_credentials,
  - Paths used are
    post /dna/intent/api/v1/global-credential/cli,
    put /dna/intent/api/v1/global-credential/cli,
"""

EXAMPLES = r"""
---
- name: Create
  cisco.dnac.cli_credential:
    dnac_host: "{{dnac_host}}"
    dnac_username: "{{dnac_username}}"
    dnac_password: "{{dnac_password}}"
    dnac_verify: "{{dnac_verify}}"
    dnac_port: "{{dnac_port}}"
    dnac_version: "{{dnac_version}}"
    dnac_debug: "{{dnac_debug}}"
    state: present
    comments: string
    credentialType: string
    description: string
    enablePassword: string
    id: string
    instanceTenantId: string
    instanceUuid: string
    password: string
    username: string
- name: Update all
  cisco.dnac.cli_credential:
    dnac_host: "{{dnac_host}}"
    dnac_username: "{{dnac_username}}"
    dnac_password: "{{dnac_password}}"
    dnac_verify: "{{dnac_verify}}"
    dnac_port: "{{dnac_port}}"
    dnac_version: "{{dnac_version}}"
    dnac_debug: "{{dnac_debug}}"
    state: present
    comments: string
    credentialType: string
    description: string
    enablePassword: string
    id: string
    instanceTenantId: string
    instanceUuid: string
    password: string
    username: string
"""
RETURN = r"""
dnac_response:
  description: A dictionary or list with the response returned by the Cisco DNAC Python SDK
  returned: always
  type: dict
  sample: >
    {
      "response": {
        "taskId": "string",
        "url": "string"
      },
      "version": "string"
    }
"""



#!/usr/bin/python
# -*- coding: utf-8 -*-

# Copyright (c) 2021, Cisco Systems
# GNU General Public License v3.0+ (see LICENSE or https://www.gnu.org/licenses/gpl-3.0.txt)

DOCUMENTATION = r"""
---
module: applications
short_description: Resource module for Applications
description:
  - Manage operations create, update and delete of the resource Applications.
  - Create new Custom application.
  - Delete existing application by its id.
  - Edit the attributes of an existing application.
version_added: '3.1.0'
extends_documentation_fragment:
  - cisco.dnac.module
author: Rafael Campos (@racampos)
options:
  id:
    description: Id query parameter. Application's Id.
    type: str
  payload:
    description: Applications's payload.
    elements: dict
    suboptions:
      applicationSet:
        description: Applications's applicationSet.
        suboptions:
          idRef:
            description: Id Ref.
            type: str
        type: dict
      name:
        description: Name.
        type: str
      networkApplications:
        description: Applications's networkApplications.
        elements: dict
        suboptions:
          appProtocol:
            description: App Protocol.
            type: str
          applicationSubType:
            description: Application Sub Type.
            type: str
          applicationType:
            description: Application Type.
            type: str
          categoryId:
            description: Category Id.
            type: str
          displayName:
            description: Display Name.
            type: str
          dscp:
            description: Dscp.
            type: str
          engineId:
            description: Engine Id.
            type: str
          helpString:
            description: Help String.
            type: str
          ignoreConflict:
            description: Ignore Conflict.
            type: str
          longDescription:
            description: Long Description.
            type: str
          name:
            description: Name.
            type: str
          popularity:
            description: Popularity.
            type: str
          rank:
            description: Rank.
            type: str
          serverName:
            description: Server Name.
            type: str
          trafficClass:
            description: Traffic Class.
            type: str
          url:
            description: Url.
            type: str
        type: list
      networkIdentity:
        description: Applications's networkIdentity.
        elements: dict
        suboptions:
          displayName:
            description: Display Name.
            type: str
          lowerPort:
            description: Lower Port.
            type: str
          ports:
            description: Ports.
            type: str
          protocol:
            description: Protocol.
            type: str
          upperPort:
            description: Upper Port.
            type: str
        type: list
    type: list
requirements:
  - dnacentersdk >= 2.11.0
  - python >= 3.12
seealso:
  - name: Cisco DNA Center documentation for Application Policy CreateApplication
    description: Complete reference of the CreateApplication API.
    link: https://developer.cisco.com/docs/dna-center/#!create-application
  - name: Cisco DNA Center documentation for Application Policy DeleteApplication
    description: Complete reference of the DeleteApplication API.
    link: https://developer.cisco.com/docs/dna-center/#!delete-application
  - name: Cisco DNA Center documentation for Application Policy EditApplication
    description: Complete reference of the EditApplication API.
    link: https://developer.cisco.com/docs/dna-center/#!edit-application
notes:
  - SDK Method used are
    application_policy.ApplicationPolicy.create_application,
    application_policy.ApplicationPolicy.delete_application,
    application_policy.ApplicationPolicy.edit_application,
  - Paths used are
    post /dna/intent/api/v1/applications,
    delete /dna/intent/api/v1/applications,
    put /dna/intent/api/v1/applications,
"""

EXAMPLES = r"""
---
- name: Delete all
  cisco.dnac.applications:
    dnac_host: "{{dnac_host}}"
    dnac_username: "{{dnac_username}}"
    dnac_password: "{{dnac_password}}"
    dnac_verify: "{{dnac_verify}}"
    dnac_port: "{{dnac_port}}"
    dnac_version: "{{dnac_version}}"
    dnac_debug: "{{dnac_debug}}"
    state: absent
    id: string
- name: Create
  cisco.dnac.applications:
    dnac_host: "{{dnac_host}}"
    dnac_username: "{{dnac_username}}"
    dnac_password: "{{dnac_password}}"
    dnac_verify: "{{dnac_verify}}"
    dnac_port: "{{dnac_port}}"
    dnac_version: "{{dnac_version}}"
    dnac_debug: "{{dnac_debug}}"
    state: present
    payload:
      - applicationSet:
          idRef: string
        name: string
        networkApplications:
          - appProtocol: string
            applicationSubType: string
            applicationType: string
            categoryId: string
            displayName: string
            dscp: string
            engineId: string
            helpString: string
            ignoreConflict: string
            longDescription: string
            name: string
            popularity: string
            rank: string
            serverName: string
            trafficClass: string
            url: string
        networkIdentity:
          - displayName: string
            lowerPort: string
            ports: string
            protocol: string
            upperPort: string
- name: Update all
  cisco.dnac.applications:
    dnac_host: "{{dnac_host}}"
    dnac_username: "{{dnac_username}}"
    dnac_password: "{{dnac_password}}"
    dnac_verify: "{{dnac_verify}}"
    dnac_port: "{{dnac_port}}"
    dnac_version: "{{dnac_version}}"
    dnac_debug: "{{dnac_debug}}"
    state: present
    payload:
      - applicationSet:
          idRef: string
        id: string
        name: string
        networkApplications:
          - appProtocol: string
            applicationSubType: string
            applicationType: string
            categoryId: string
            displayName: string
            dscp: string
            engineId: string
            helpString: string
            id: string
            ignoreConflict: string
            longDescription: string
            name: string
            popularity: string
            rank: string
            serverName: string
            trafficClass: string
            url: string
        networkIdentity:
          - displayName: string
            id: string
            lowerPort: string
            ports: string
            protocol: string
            upperPort: string
"""
RETURN = r"""
dnac_response:
  description: A dictionary or list with the response returned by the Cisco DNAC Python SDK
  returned: always
  type: dict
  sample: >
    {
      "response": {
        "taskId": "string",
        "url": "string"
      },
      "version": "string"
    }
"""



#!/usr/bin/python
# -*- coding: utf-8 -*-

# Copyright (c) 2021, Cisco Systems
# GNU General Public License v3.0+ (see LICENSE or https://www.gnu.org/licenses/gpl-3.0.txt)

DOCUMENTATION = r"""
---
module: network_devices_network_profiles_for_sites_info
short_description: Information module for Network Devices Network Profiles For Sites
description:
  - Get all Network Devices Network Profiles For Sites.
  - Get Network Devices Network Profiles For Sites by id.
  - Retrieves a network profile for sites by id.
  - Retrieves the list of network profiles for sites.
version_added: '6.15.0'
extends_documentation_fragment:
  - cisco.dnac.module_info
author: Rafael Campos (@racampos)
options:
  headers:
    description: Additional headers.
    type: dict
  offset:
    description:
      - Offset query parameter. The first record to show for this page; the first record is numbered 1.
    type: int
  limit:
    description:
      - Limit query parameter. The number of records to show for this page;The minimum is 1, and the maximum is 500.
    type: int
  sortBy:
    description:
      - SortBy query parameter. A property within the response to sort by.
    type: str
  order:
    description:
      - Order query parameter. Whether ascending or descending order should be used to sort the response.
    type: str
  type:
    description:
      - Type query parameter. Filter responses to only include profiles of a given type.
    type: str
  id:
    description:
      - Id path parameter. The `id` of the network profile, retrievable from `GET /intent/api/v1/networkProfilesForSites`.
    type: str
requirements:
  - dnacentersdk >= 2.11.0
  - python >= 3.12
seealso:
  - name: Cisco DNA Center documentation for Site Design RetrieveANetworkProfileForSitesById
    description: Complete reference of the RetrieveANetworkProfileForSitesById API.
    link: https://developer.cisco.com/docs/dna-center/#!retrieve-a-network-profile-for-sites-by-id
  - name: Cisco DNA Center documentation for Site Design RetrievesTheListOfNetworkProfilesForSites
    description: Complete reference of the RetrievesTheListOfNetworkProfilesForSites API.
    link: https://developer.cisco.com/docs/dna-center/#!retrieves-the-list-of-network-profiles-for-sites
notes:
  - SDK Method used are
    site_design.SiteDesign.retrieve_a_network_profile_for_sites_by_id,
    site_design.SiteDesign.retrieves_the_list_of_network_profiles_for_sites,
  - Paths used are
    get /dna/intent/api/v1/networkProfilesForSites,
    get /dna/intent/api/v1/networkProfilesForSites/{id},
"""

EXAMPLES = r"""
---
- name: Get all Network Devices Network Profiles For Sites
  cisco.dnac.network_devices_network_profiles_for_sites_info:
    dnac_host: "{{dnac_host}}"
    dnac_username: "{{dnac_username}}"
    dnac_password: "{{dnac_password}}"
    dnac_verify: "{{dnac_verify}}"
    dnac_port: "{{dnac_port}}"
    dnac_version: "{{dnac_version}}"
    dnac_debug: "{{dnac_debug}}"
    headers: "{{my_headers | from_json}}"
    offset: 0
    limit: 0
    sortBy: string
    order: string
    type: string
  register: result
- name: Get Network Devices Network Profiles For Sites by id
  cisco.dnac.network_devices_network_profiles_for_sites_info:
    dnac_host: "{{dnac_host}}"
    dnac_username: "{{dnac_username}}"
    dnac_password: "{{dnac_password}}"
    dnac_verify: "{{dnac_verify}}"
    dnac_port: "{{dnac_port}}"
    dnac_version: "{{dnac_version}}"
    dnac_debug: "{{dnac_debug}}"
    headers: "{{my_headers | from_json}}"
    id: string
  register: result
"""
RETURN = r"""
dnac_response:
  description: A dictionary or list with the response returned by the Cisco DNAC Python SDK
  returned: always
  type: dict
  sample: >
    {
      "response": {
        "id": "string",
        "name": "string",
        "type": "string"
      }
    }
"""



#!/usr/bin/python
# -*- coding: utf-8 -*-

# Copyright (c) 2021, Cisco Systems
# GNU General Public License v3.0+ (see LICENSE or https://www.gnu.org/licenses/gpl-3.0.txt)

DOCUMENTATION = r"""
---
module: maps_supported_access_points_info
short_description: Information module for Maps Supported Access Points
description:
  - Get all Maps Supported Access Points.
  - Gets the list of supported access point types as well as valid antenna pattern names that can be used for each.
version_added: '6.14.0'
extends_documentation_fragment:
  - cisco.dnac.module_info
author: Rafael Campos (@racampos)
options:
  headers:
    description: Additional headers.
    type: dict
requirements:
  - dnacentersdk >= 2.11.0
  - python >= 3.12
seealso:
  - name: Cisco DNA Center documentation for Sites MapsSupportedAccessPoints
    description: Complete reference of the MapsSupportedAccessPoints API.
    link: https://developer.cisco.com/docs/dna-center/#!maps-supported-access-points
notes:
  - SDK Method used are
    sites.Sites.maps_supported_access_points,
  - Paths used are
    get /dna/intent/api/v1/maps/supported-access-points,
"""

EXAMPLES = r"""
---
- name: Get all Maps Supported Access Points
  cisco.dnac.maps_supported_access_points_info:
    dnac_host: "{{dnac_host}}"
    dnac_username: "{{dnac_username}}"
    dnac_password: "{{dnac_password}}"
    dnac_verify: "{{dnac_verify}}"
    dnac_port: "{{dnac_port}}"
    dnac_version: "{{dnac_version}}"
    dnac_debug: "{{dnac_debug}}"
    headers: "{{my_headers | from_json}}"
  register: result
"""
RETURN = r"""
dnac_response:
  description: A dictionary or list with the response returned by the Cisco DNAC Python SDK
  returned: always
  type: list
  elements: dict
  sample: >
    [
      {
        "antennaPatterns": [
          {
            "band": "string",
            "names": [
              "string"
            ]
          }
        ],
        "apType": "string"
      }
    ]
"""



#!/usr/bin/python
# -*- coding: utf-8 -*-

# Copyright (c) 2021, Cisco Systems
# GNU General Public License v3.0+ (see LICENSE or https://www.gnu.org/licenses/gpl-3.0.txt)

DOCUMENTATION = r"""
---
module: filter_group_associations_info
short_description: Information module for Filter Group Associations
description:
  - Get all Filter Group Associations. - > Returns the details of filter group associations for the given parameters. For
    detailed information about the usage of the API, please refer to the Open API specification document - https //github.com/cisco-en-
    programmability/catalyst-center-api-specs/blob/main/Assurance/CE_Cat_Center_Org- FilterGroups-1.0.0-resolved.yaml.
version_added: '6.46.0'
extends_documentation_fragment:
  - cisco.dnac.module_info
author: Rafael Campos (@racampos)
options:
  headers:
    description: Additional headers.
    type: dict
  filterGroupId:
    description:
      - >
        FilterGroupId query parameter. Filter Group id. Examples
        `?filterGroupId=2ee1b9f0-8036-443b-bad0-7692760af1b5`(single id requested)
        `?filterGroupId=2ee1b9f0-8036-443b-bad0-7692760af1b5&filterGroupId=ae368f0b-f4e3-4e8f-a914-011cbd19bb51`
        (multiple ids requested).
    type: str
  entityId:
    description:
      - >
        EntityId query parameter. Entity id with which the filter group is associated. Examples
        `?entityId=2ee1b9f0-8036-443b-bad0-7692760af1b5`(single id requested)
        `?entityId=2ee1b9f0-8036-443b-bad0-7692760af1b5&entityId=ae368f0b-f4e3-4e8f-a914-011cbd19bb51` (multiple
        ids requested).
    type: str
  entityType:
    description:
      - >
        EntityType query parameter. Type of the entity with which the filter group is associated. Examples
        `?entityType=Issue Settings`(single type requested) `?entityType=Custom Dashboard&entityType=Issue
        Settings` (multiple types requested).
    type: str
requirements:
  - dnacentersdk >= 2.11.0
  - python >= 3.12
seealso:
  - name: Cisco DNA Center documentation for Devices GetTheFilterGroupAssociations
    description: Complete reference of the GetTheFilterGroupAssociations API.
    link: https://developer.cisco.com/docs/dna-center/#!get-the-filter-group-associations
notes:
  - SDK Method used are
    devices.Devices.get_the_filter_group_associations,
  - Paths used are
    get /dna/intent/api/v1/filterGroupAssociations,
"""

EXAMPLES = r"""
---
- name: Get all Filter Group Associations
  cisco.dnac.filter_group_associations_info:
    dnac_host: "{{dnac_host}}"
    dnac_username: "{{dnac_username}}"
    dnac_password: "{{dnac_password}}"
    dnac_verify: "{{dnac_verify}}"
    dnac_port: "{{dnac_port}}"
    dnac_version: "{{dnac_version}}"
    dnac_debug: "{{dnac_debug}}"
    headers: "{{my_headers | from_json}}"
    filterGroupId: string
    entityId: string
    entityType: string
  register: result
"""
RETURN = r"""
dnac_response:
  description: A dictionary or list with the response returned by the Cisco DNAC Python SDK
  returned: always
  type: dict
  sample: >
    {
      "response": [
        {
          "id": "string",
          "filterGroupId": "string",
          "entityId": "string",
          "entityName": "string",
          "entityType": "string"
        }
      ],
      "version": "string"
    }
"""



#!/usr/bin/python
# -*- coding: utf-8 -*-

# Copyright (c) 2021, Cisco Systems
# GNU General Public License v3.0+ (see LICENSE or https://www.gnu.org/licenses/gpl-3.0.txt)

DOCUMENTATION = r"""
---
module: iot_network_devices_network_device_id_mrp_rings_id_members_info
short_description: Information module for Iot Network Devices  Network Device Id Mrp Rings Id Members
description:
  - Get all Iot Network Devices  Network Device Id Mrp Rings Id Members. - > This API returns the list of MRP ring members
    for the given fields - networkDeviceId Network device ID of the MRP ring member. The networkDeviceId is the instanceUuid
    attribute in the response of API - /dna/intent/api/v1/networkDevices and id ID of the MRP ring. The id of the configured
    MRP Ring can be retrieved using the API /dna/intent/api/v1/iot/networkDevices/${networkDeviceId}/mrpRings .
version_added: '6.18.0'
extends_documentation_fragment:
  - cisco.dnac.module_info
author: Rafael Campos (@racampos)
options:
  headers:
    description: Additional headers.
    type: dict
  networkDeviceId:
    description:
      - NetworkDeviceId path parameter. Network device ID of the MRP ring member.
    type: str
  id:
    description:
      - Id path parameter. ID of the MRP ring.
    type: float
  offset:
    description:
      - Offset query parameter. The first record to show for this page; the first record is numbered 1.
    type: int
  limit:
    description:
      - Limit query parameter. The number of records to show for this page.
    type: int
requirements:
  - dnacentersdk >= 2.11.0
  - python >= 3.12
seealso:
  - name: Cisco DNA Center documentation for Industrial Configuration RetrievesTheListOfNetworkDevicesPartOfMRPRing
    description: Complete reference of the RetrievesTheListOfNetworkDevicesPartOfMRPRing API.
    link: https://developer.cisco.com/docs/dna-center/#!retrieves-the-list-of-network-devices-part-of-mrp-ring
notes:
  - SDK Method used are
    industrial_configuration.IndustrialConfiguration.retrieves_the_list_of_network_devices_part_of_m_r_p_ring,
  - Paths used are
    get /dna/intent/api/v1/iot/networkDevices/{networkDeviceId}/mrpRings/{id}/members,
"""

EXAMPLES = r"""
---
- name: Get all Iot Network Devices  Network Device Id Mrp Rings Id Members
  cisco.dnac.iot_network_devices_network_device_id_mrp_rings_id_members_info:
    dnac_host: "{{dnac_host}}"
    dnac_username: "{{dnac_username}}"
    dnac_password: "{{dnac_password}}"
    dnac_verify: "{{dnac_verify}}"
    dnac_port: "{{dnac_port}}"
    dnac_version: "{{dnac_version}}"
    dnac_debug: "{{dnac_debug}}"
    headers: "{{my_headers | from_json}}"
    offset: 0
    limit: 0
    networkDeviceId: string
    id: 0
  register: result
"""
RETURN = r"""
dnac_response:
  description: A dictionary or list with the response returned by the Cisco DNAC Python SDK
  returned: always
  type: list
  elements: dict
  sample: >
    [
      {
        "response": [
          {
            "networkDeviceId": "string",
            "id": 0,
            "deviceName": "string",
            "domainId": "string",
            "portName1": "string",
            "portName2": "string",
            "port1Status": "string",
            "port2Status": "string",
            "operationMode": "string",
            "configurationMode": "string"
          }
        ],
        "version": 0
      }
    ]
"""



#!/usr/bin/python
# -*- coding: utf-8 -*-

# Copyright (c) 2021, Cisco Systems
# GNU General Public License v3.0+ (see LICENSE or https://www.gnu.org/licenses/gpl-3.0.txt)

DOCUMENTATION = r"""
---
module: discoverys_jobs_info
short_description: Information module for Discoverys Jobs
description:
  - Get all Discoverys Jobs.
  - Get Discoverys Jobs by id. - > API to get all the discovery job details by discovery id. A discovery can have multiple
    discovery jobs, created against the same discovery id.
  - This API retrieves the details of a specific discovery job using the given job id and discovery id.
version_added: '6.46.0'
extends_documentation_fragment:
  - cisco.dnac.module_info
author: Rafael Campos (@racampos)
options:
  headers:
    description: Additional headers.
    type: dict
  discoveryId:
    description:
      - DiscoveryId path parameter. The id of the discovery.
    type: str
  jobId:
    description:
      - JobId path parameter. The id of the discovery job.
    type: str
  id:
    description:
      - Id path parameter. The id of the discovery.
    type: str
  limit:
    description:
      - Limit query parameter. The number of records to show for this page.
    type: int
  offset:
    description:
      - Offset query parameter. The first record to show for this page; the first record is numbered 1.
    type: int
  orderBy:
    description:
      - >
        OrderBy query parameter. To fetch the latest discovery job. Use the orderBy query parameter with values
        such as startTime or endTime. By default, jobs are ordered by startTime in descending order to display
        the most recent entries first.
    type: str
requirements:
  - dnacentersdk >= 2.11.0
  - python >= 3.12
seealso:
  - name: Cisco DNA Center documentation for Devices FetchesAllTheDiscoveryJobDetailsByDiscoveryId
    description: Complete reference of the FetchesAllTheDiscoveryJobDetailsByDiscoveryId API.
    link: https://developer.cisco.com/docs/dna-center/#!fetches-all-the-discovery-job-details-by-discovery-id
  - name: Cisco DNA Center documentation for Devices FetchesTheDiscoveryJobDetailsForTheGivenJobId
    description: Complete reference of the FetchesTheDiscoveryJobDetailsForTheGivenJobId API.
    link: https://developer.cisco.com/docs/dna-center/#!fetches-the-discovery-job-details-for-the-given-job-id
notes:
  - SDK Method used are
    devices.Devices.fetches_all_the_discovery_job_details_by_discovery_id,
    devices.Devices.fetches_the_discovery_job_details_for_the_given_job_id,
  - Paths used are
    get /dna/intent/api/v1/discoverys/{discoveryId}/jobs/{jobId},
    get /dna/intent/api/v1/discoverys/{id}/jobs,
"""

EXAMPLES = r"""
---
- name: Get all Discoverys Jobs
  cisco.dnac.discoverys_jobs_info:
    dnac_host: "{{dnac_host}}"
    dnac_username: "{{dnac_username}}"
    dnac_password: "{{dnac_password}}"
    dnac_verify: "{{dnac_verify}}"
    dnac_port: "{{dnac_port}}"
    dnac_version: "{{dnac_version}}"
    dnac_debug: "{{dnac_debug}}"
    headers: "{{my_headers | from_json}}"
    jobId: string
    limit: 0
    offset: 0
    orderBy: string
    id: string
  register: result
- name: Get Discoverys Jobs by id
  cisco.dnac.discoverys_jobs_info:
    dnac_host: "{{dnac_host}}"
    dnac_username: "{{dnac_username}}"
    dnac_password: "{{dnac_password}}"
    dnac_verify: "{{dnac_verify}}"
    dnac_port: "{{dnac_port}}"
    dnac_version: "{{dnac_version}}"
    dnac_debug: "{{dnac_debug}}"
    headers: "{{my_headers | from_json}}"
    discoveryId: string
    jobId: string
  register: result
"""
RETURN = r"""
dnac_response:
  description: A dictionary or list with the response returned by the Cisco DNAC Python SDK
  returned: always
  type: dict
  sample: >
    {
      "response": {
        "name": "string",
        "managementIpSelectionMethod": "string",
        "discoveryTypeDetails": {
          "type": "string",
          "ipAddress": "string",
          "range": [
            {
              "ipAddressStart": "string",
              "ipAddressEnd": "string"
            }
          ],
          "cidrAddress": {
            "cidrPrefix": "string",
            "cidrSuffix": 0
          },
          "subnetFilter": {
            "ipAddress": "string",
            "cidrAddress": {
              "cidrPrefix": "string",
              "cidrSuffix": 0
            }
          },
          "hopCount": 0
        },
        "onlyNewDevice": true,
        "updateManagementIp": true,
        "credentials": {
          "cli": {
            "description": "string",
            "username": "string",
            "globalCredentialIdList": [
              "string"
            ],
            "protocolOrder": "string"
          },
          "snmp": {
            "snmpV2Read": {
              "description": "string",
              "globalCredentialIdList": [
                "string"
              ]
            },
            "snmpV2Write": {
              "description": "string",
              "globalCredentialIdList": [
                "string"
              ]
            },
            "snmpV3": {
              "description": "string",
              "mode": "string",
              "username": "string",
              "authType": "string",
              "privacyType": "string",
              "globalCredentialIdList": [
                "string"
              ]
            },
            "retries": 0,
            "timeout": 0
          },
          "httpRead": {
            "description": "string",
            "username": "string",
            "port": 0,
            "protocol": "string",
            "globalCredentialIdList": [
              "string"
            ]
          },
          "httpWrite": {
            "description": "string",
            "username": "string",
            "port": 0,
            "protocol": "string",
            "globalCredentialIdList": [
              "string"
            ]
          },
          "netconf": {
            "port": 0,
            "description": "string",
            "globalCredentialIdList": [
              "string"
            ]
          }
        }
      },
      "version": "string"
    }
"""
